@@ -14,7 +14,11 @@ class GraphRenderer:
         d = Digraph()
 
         for node in sorted(self.graph.nodes):
-            d.node(name=node.path.name, **node.style.to_dict())
+            node_options = node.style.to_dict()
+            # 描画する node の配下に位置する node が存在する場合には、 shape=record として表示する
+            if self.graph.child_node_exists(node):
+                node_options["shape"] = "record"
+            d.node(name=node.path.name, **node_options)
 
         for edge in sorted(self.graph.edges):
             d.edge(edge.tail.name, edge.head.name, **edge.style.to_dict())
